==> nextcloud-16.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "_" : "_",
    "An error occurred while generating your backup codes" : "Beim Erstellen Ihrer Backup-Codes ist ein Fehler aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Ihre Backup-Codes. Bitte speichern und/oder drucken Sie diese, da diese Codes später nicht mehr gelesen werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Sie die Backup-Codes erneuern, werden die alten Codes automatisch ungültig.",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You created two-factor backup codes for your account" : "Sie haben Zwei-Faktor Sicherungs-Codes für Ihr Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Verwende Backup-Code",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwenden Sie einen der Backup-Codes, den Sie bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert haben.",
    "Submit" : "Übermitteln",
    "Backup codes have been generated. {{used}} of {{total}} codes have been used." : "Backup-Codes wurden erzeugt. {{used}} von {{total}} Codes wurden benutzt.",
    "Nextcloud backup codes" : "Nextcloud Backup-Codes",
    "activated" : "Aktiviert",
    "updated" : "Aktualisiert",
    "mounted" : "Eingebunden",
    "deactivated" : "Deaktiviert",
    "beforeCreate" : "beforeCreate",
    "created" : "Erstellt",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "Vernichtet",
    "beforeMount" : "beforeMount",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes generiert. Bitte holen Sie dies für den Fall, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren, nach."
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/twofactor_backupcodes/l10n/de_DE.js <==
OC.L10N.register(
    "twofactor_backupcodes",
    {
    "function" : "Funktion",
    "_" : "_",
    "An error occurred while generating your backup codes" : "Beim Erstellen Ihrer Backup-Codes ist ein Fehler aufgetreten",
    "{name} backup codes" : "{name} Backup-Codes",
    "These are your backup codes. Please save and/or print them as you will not be able to read the codes again later" : "Dies sind Ihre Backup-Codes. Bitte speichern und/oder drucken Sie diese, da diese Codes später nicht mehr gelesen werden können",
    "Save backup codes" : "Backup-Codes speichern",
    "Print backup codes" : "Backup-Codes drucken",
    "Backup codes have been generated. {used} of {total} codes have been used." : "Backup-Codes wurden erzeugt. {used} von {total} Codes wurden benutzt.",
    "Regenerate backup codes" : "Backup-Codes erneuern",
    "_icon-loading-small_::_generate-backup-codes_" : ["icon-loading-small","generate-backup-codes"],
    "If you regenerate backup codes, you automatically invalidate old codes." : "Wenn Sie die Backup-Codes erneuern, werden die alten Codes automatisch ungültig.",
    "Generate backup codes" : "Backup-Codes erzeugen",
    "You created two-factor backup codes for your account" : "Sie haben Zwei-Faktor Sicherungs-Codes für Ihr Konto erstellt",
    "Second-factor backup codes" : "Zweitfaktor Backup-Codes",
    "You enabled two-factor authentication but did not generate backup codes yet. They are needed to restore access to your account in case you lose your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes erzeugt. Diese werden für den Fall benötigt, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren.",
    "Backup code" : "Backup-Code",
    "Use backup code" : "Verwende Backup-Code",
    "Two factor backup codes" : "Zweifaktor-Backup-Codes",
    "A two-factor auth backup codes provider" : "Ein Anbieter für Zweifaktor-Backup-Codes",
    "Use one of the backup codes you saved when setting up two-factor authentication." : "Verwenden Sie einen der Backup-Codes, den Sie bei der Einrichtung der Zwei-Faktor-Authentifizierung gespeichert haben.",
    "Submit" : "Übermitteln",
    "activated" : "Aktiviert",
    "updated" : "Aktualisiert",
    "mounted" : "Eingebunden",
    "deactivated" : "Deaktiviert",
    "beforeCreate" : "beforeCreate",
    "created" : "Erstellt",
    "beforeUpdate" : "beforeUpdate",
    "beforeDestroy" : "beforeDestroy",
    "destroyed" : "Vernichtet",
    "beforeMount" : "beforeMount",
    "Nextcloud backup codes" : "Nextcloud Backup-Codes",
    "You have enabled two-factor authentication but have not yet generated backup codes. Be sure to do this in case you lose access to your second factor." : "Sie haben die Zwei-Faktor-Authentifizierung aktiviert, aber noch keine Backup-Codes generiert. Bitte holen Sie dies für den Fall, dass Sie den Zugriff auf Ihren zweiten Faktor verlieren, nach."
},
"nplurals=2; plural=(n != 1);");
